@@ -188,11 +188,13 @@
   c(
     "3" = "passingYards",
     "4" = "passingTouchdowns",
+    "8" = "passing25Yards",
     "19" = "passing2PtConversions",
     "20" = "passingInterceptions",
     "24" = "rushingYards",
     "25" = "rushingTouchdowns",
     "26" = "rushing2PtConversions",
+    "28" = "rushing10Yards",
     "35" = "rushing40YardTD",
     "37" = "rushing100YardGame",
     "38" = "rushing200YardGame",
@@ -200,6 +202,7 @@
     "43" = "receivingTouchdowns",
     "44" = "receiving2PtConversions",
     "45" = "receiving40YardTD",
+    "48" = "receiving10Yards",
     "53" = "receivingReceptions",
     "56" = "receiving100YardGame",
     "57" = "receiving200YardGame",
@@ -229,6 +232,7 @@
     "104" = "interceptionReturnTouchdown",
     "114" = "kickoffReturnYards",
     "115" = "puntReturnYards",
+    "122" = "defensive22To27PointsAllowed",
     "123" = "defensive28To34PointsAllowed",
     "124" = "defensive35To45PointsAllowed",
     "125" = "defensive46+PointsAllowed",
