@@ -1,6 +1,6 @@
 test_that("nflfastr dataframes are fetched", {
-  skippy()
   skip_on_cran()
+  skip_if_not(github_online())
 
   weekly <- nflfastr_weekly(seasons = 2019:2020, type = "offense")
   rosters <- nflfastr_rosters(seasons = 2019:2020)
